summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvaspolygonalitem_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvaspolygonalitem_imp.h')
-rw-r--r--kjsembed/qtbindings/qcanvaspolygonalitem_imp.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kjsembed/qtbindings/qcanvaspolygonalitem_imp.h b/kjsembed/qtbindings/qcanvaspolygonalitem_imp.h
index 389ed346..80ff4445 100644
--- a/kjsembed/qtbindings/qcanvaspolygonalitem_imp.h
+++ b/kjsembed/qtbindings/qcanvaspolygonalitem_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQCanvasPolygonalItem;
+class TTQCanvasPolygonalItem;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQCanvasPolygonalItem;
namespace KJSEmbed {
/**
* Wrapper class for TQCanvasPolygonalItem methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QCanvasPolygonalItemImp : public JSProxyImp
+class TQCanvasPolygonalItemImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -46,8 +46,8 @@ public:
Method_Last = -1
};
- QCanvasPolygonalItemImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QCanvasPolygonalItemImp();
+ TQCanvasPolygonalItemImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQCanvasPolygonalItemImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -61,13 +61,13 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQCanvasPolygonalItem *toQCanvasPolygonalItem( KJS::Object &object );
+ static TTQCanvasPolygonalItem *toTQCanvasPolygonalItem( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QCanvasPolygonalItem_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasPolygonalItem_1( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -100,7 +100,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQCanvasPolygonalItem *instance; // Temp
+ TTQCanvasPolygonalItem *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQCanvasPolygonalItem;
namespace KJSEmbed {
/**
- * Wrapper class for TQCanvasPolygonalItem methods.
+ * Wrapper class for TTQCanvasPolygonalItem methods.
*
* @author Richard Moore, rich@kde.org